<?php
//error_reporting(E_ALL);

/**
 * ȥȥ饯饹ɤ߹
 */
require_once '{{SYL_DIR}}/SyL.php';

/**
 * ưѥ᡼
 *
 *  project_dir - ץȥǥ쥯ȥ
 *  app_name    - ץꥱ̾
 *  action_key  - ѥ᡼Υ̾
 *  cache       - åˡʢ̤ϤǥåѤʤ
 */
$config = array(
  'project_dir'  => '{{PROJECT_DIR}}',
  'app_name'     => '{{APP_NAME}}',
  'action_key'   => 'action',
  'cache'        => 'file'
);

/**
 * ե졼ư
 */
SyL_Controller::streaming($config);

?>
